[−][src]Enum cranelift_codegen_meta::cdsl::instructions::TypePredicateNode
Variants
Is the value argument (at the index designated by the first member) the same type as the type name (second member)?
CtrlTypeVarCheck(String)Is the controlling type variable the same type as the one designated by the type name (only member)?
Implementations
impl TypePredicateNode[src]
fn rust_predicate(&self, func_str: &str) -> String[src]