[−][src]Struct cranelift_codegen_meta::cdsl::instructions::InstructionPredicateRegistry
A registry of predicates to help deduplicating them, during Encodings construction. When the
construction process is over, it needs to be extracted with extract and associated to the
TargetIsa.
Fields
map: PrimaryMap<InstructionPredicateNumber, InstructionPredicate>Maps a predicate number to its actual predicate.
inverted_map: HashMap<InstructionPredicate, InstructionPredicateNumber>Inverse map: maps a predicate to its predicate number. This is used before inserting a predicate, to check whether it already exists.
Implementations
impl InstructionPredicateRegistry[src]
pub fn new() -> Self[src]
pub fn insert(
&mut self,
predicate: InstructionPredicate
) -> InstructionPredicateNumber[src]
&mut self,
predicate: InstructionPredicate
) -> InstructionPredicateNumber
pub fn extract(
self
) -> PrimaryMap<InstructionPredicateNumber, InstructionPredicate>[src]
self
) -> PrimaryMap<InstructionPredicateNumber, InstructionPredicate>