[−][src]Struct cranelift_codegen_meta::cdsl::isa::TargetIsa
Fields
name: &'static strinstructions: InstructionGroupsettings: SettingGroupregs: IsaRegsrecipes: PrimaryMap<EncodingRecipeNumber, EncodingRecipe>cpu_modes: Vec<CpuMode>encodings_predicates: PrimaryMap<InstructionPredicateNumber, InstructionPredicate>local_transform_groups: Vec<TransformGroupIndex>TransformGroupIndex are global to all the ISAs, while we want to have indices into the local array of transform groups that are directly used. We use this map to get this information.
Implementations
impl TargetIsa[src]
pub fn new(
name: &'static str,
instructions: InstructionGroup,
settings: SettingGroup,
regs: IsaRegs,
recipes: PrimaryMap<EncodingRecipeNumber, EncodingRecipe>,
cpu_modes: Vec<CpuMode>,
encodings_predicates: PrimaryMap<InstructionPredicateNumber, InstructionPredicate>
) -> Self[src]
name: &'static str,
instructions: InstructionGroup,
settings: SettingGroup,
regs: IsaRegs,
recipes: PrimaryMap<EncodingRecipeNumber, EncodingRecipe>,
cpu_modes: Vec<CpuMode>,
encodings_predicates: PrimaryMap<InstructionPredicateNumber, InstructionPredicate>
) -> Self
pub fn transitive_transform_groups(
&self,
all_groups: &TransformGroups
) -> Vec<TransformGroupIndex>[src]
&self,
all_groups: &TransformGroups
) -> Vec<TransformGroupIndex>
Returns a deterministically ordered, deduplicated list of TransformGroupIndex for the transitive set of TransformGroup this TargetIsa uses.
pub fn direct_transform_groups(&self) -> &Vec<TransformGroupIndex>[src]
Returns a deterministically ordered, deduplicated list of TransformGroupIndex for the directly reachable set of TransformGroup this TargetIsa uses.
pub fn translate_group_index(&self, group_index: TransformGroupIndex) -> usize[src]