[−][src]Struct cranelift_codegen_meta::cdsl::recipes::Register
A specific register in a register class.
A register is identified by the top-level register class it belongs to and its first register unit.
Specific registers are used to describe constraints on instructions where some operands must use a fixed register.
Register instances can be created with the constructor, or accessed as
attributes on the register class: GPR.rcx.
Fields
regclass: RegClassIndexunit: u8Implementations
impl Register[src]
pub fn new(regclass: RegClassIndex, unit: u8) -> Self[src]