[−][src]Struct cranelift_codegen_meta::cdsl::recipes::Stack
An operand that must be in a stack slot.
A Stack object can be used to indicate an operand constraint for a value
operand that must live in a stack slot.
Fields
regclass: RegClassIndexImplementations
impl Stack[src]
pub fn new(regclass: RegClassIndex) -> Self[src]
pub fn stack_base_mask(self) -> &'static str[src]