[−][src]Enum cranelift_codegen_meta::cdsl::settings::ProtoSpecificSetting
This is the basic information needed to track the specific parts of a setting when building them.
Variants
Bool(bool)Num(u8)Auto Trait Implementations
impl RefUnwindSafe for ProtoSpecificSetting[src]
impl Send for ProtoSpecificSetting[src]
impl Sync for ProtoSpecificSetting[src]
impl Unpin for ProtoSpecificSetting[src]
impl UnwindSafe for ProtoSpecificSetting[src]