DynamicVectorType

Struct DynamicVectorType 

pub(crate) struct DynamicVectorType {
    base: LaneType,
    unscaled_lanes: u64,
}
A concrete dynamic SIMD vector type.

A vector type has a lane type which is an instance of LaneType, and a positive number of lanes.

Fields

base: LaneTypeunscaled_lanes: u64

Implementations

Source

impl DynamicVectorType

pub fn new(base: LaneType, unscaled_lanes: u64) -> Self

Initialize a new type with base lane type and a minimum number of lanes.

pub fn doc(&self) -> String

Return a string containing the documentation comment for this vector type.

pub fn lane_bits(&self) -> u64

Return the number of bits in a lane.

pub fn minimum_lane_count(&self) -> u64

Return the number of lanes.

pub fn lane_type(&self) -> LaneType

Return the lane type.

pub fn number(&self) -> u16

Find the unique number associated with this vector type.

Dynamic vector types are encoded in the same manner as VectorType, with lane type in the low 4 bits and the log2(lane_count). We add the VECTOR_BASE to move these numbers into the range beyond the fixed SIMD types.