TypeSet

Struct TypeSet 

pub(crate) struct TypeSet {
    pub lanes: BTreeSet<u16>,
    pub dynamic_lanes: BTreeSet<u16>,
    pub ints: BTreeSet<u16>,
    pub floats: BTreeSet<u16>,
}

Fields

lanes: BTreeSet<u16>dynamic_lanes: BTreeSet<u16>ints: BTreeSet<u16>floats: BTreeSet<u16>

Implementations

Source

impl TypeSet

fn new( lanes: BTreeSet<u16>, dynamic_lanes: BTreeSet<u16>, ints: BTreeSet<u16>, floats: BTreeSet<u16>, ) -> Self

pub fn size(&self) -> usize

Return the number of concrete types represented by this typeset.

fn image(&self, derived_func: DerivedFunc) -> TypeSet

Return the image of self across the derived function func.

fn lane_of(&self) -> TypeSet

Return a TypeSet describing the image of self across lane_of.

fn as_truthy(&self) -> TypeSet

Return a TypeSet describing the image of self across as_truthy.

fn half_width(&self) -> TypeSet

Return a TypeSet describing the image of self across halfwidth.

fn double_width(&self) -> TypeSet

Return a TypeSet describing the image of self across doublewidth.

fn half_vector(&self) -> TypeSet

Return a TypeSet describing the image of self across halfvector.

fn double_vector(&self) -> TypeSet

Return a TypeSet describing the image of self across doublevector.

fn dynamic_to_vector(&self) -> TypeSet

fn concrete_types(&self) -> Vec<ValueType>

fn get_singleton(&self) -> ValueType

Return the singleton type represented by self. Can only call on typesets containing 1 type.