[−][src]Struct cranelift_codegen_meta::cdsl::xform::TransformGroupBuilder
Fields
name: &'static strdoc: &'static strchain_with: Option<TransformGroupIndex>isa_name: Option<&'static str>custom_legalizes: HashMap<String, &'static str>transforms: Vec<Transform>Implementations
impl TransformGroupBuilder[src]
pub fn new(name: &'static str, doc: &'static str) -> Self[src]
pub fn chain_with(self, next_id: TransformGroupIndex) -> Self[src]
pub fn isa(self, isa_name: &'static str) -> Self[src]
pub fn custom_legalize(
&mut self,
inst: &Rc<InstructionContent>,
func_name: &'static str
)[src]
&mut self,
inst: &Rc<InstructionContent>,
func_name: &'static str
)
Add a custom legalization action for inst.
The func_name parameter is the fully qualified name of a Rust function which takes the
same arguments as the isa::Legalize actions.
The custom function will be called to legalize inst and any return value is ignored.
pub fn legalize(&mut self, src: DummyDef, dst: Vec<DummyDef>)[src]
Add a legalization pattern to this group.
pub fn build_and_add_to(
self,
owner: &mut TransformGroups
) -> TransformGroupIndex[src]
self,
owner: &mut TransformGroups
) -> TransformGroupIndex