gen_one_imm_inst_builder

Function gen_one_imm_inst_builder 

fn gen_one_imm_inst_builder(
    inst: &Rc<InstructionContent>,
    fmt: &mut Formatter,
    suffix: &str,
    signed: bool,
    deprecation: Option<&str>,
)
Emit a single immediate convenience method for inst with the given method name suffix (e.g. "_imm_s"). signed selects sign- vs zero-extension of the materialized immediate, and deprecation, if set, marks the method #[deprecated] with the given note.