This crate generates Rust sources for use by
cranelift_codegen.
Modules
- cdsl ๐
- Cranelift DSL classes.
- default_
map ๐ - Trait for extending
HashMapwithget_or_default. - error
- Error returned during meta code-generation.
- gen_
binemit ๐ - Generate binary emission code for each ISA.
- gen_
encodings ๐ - Generate sources for instruction encoding.
- gen_
inst ๐ - Generate instruction data (including opcodes, formats, builders, etc.).
- gen_
legalizer ๐ - Generate transformations to legalize instructions without encodings.
- gen_
registers ๐ - Generate the ISA-specific registers.
- gen_
settings ๐ - Generate the ISA-specific settings.
- gen_
types ๐ - Generate sources with type info.
- isa
- Define supported ISAs; includes ISA-specific instructions, encodings, registers, settings, etc.
- shared ๐
- Shared definitions for the Cranelift intermediate language.
- srcgen ๐
- Source code generator.
- unique_
table ๐ - An index-accessed table implementation that avoids duplicate entries.
Macros
- predicate
- A macro that converts boolean settings into predicates to look more natural.
- preset
- A macro that joins boolean settings into a list (e.g.
preset!(feature_a && feature_b)).
Functions
- generate
- Generates all the Rust source files used in Cranelift from the meta-language.
- isa_
from_ arch - Generate an ISA from an architecture string (e.g. โx86_64โ).